// you should not need to change this class
import java.io.PrintStream;

public class Simulator {
   private PhysicsElement[] elements = null;
   private PrintStream out;
   
   public Simulator(){
      out = System.out;
   };
   public Simulator(PrintStream out) {
      this.out = out;
   };
   public Simulator (PrintStream out, PhysicsElement[] e){
      this.out = out;
      elements = e;
   };
   public void setPhysicsElements ( PhysicsElement[] e){
      elements = e;
   }
   private void printSystemHeaders() {
      if (elements == null) return;
      out.print("time,");
      for (int i=0; i<elements.length; i++)  // print header
         out.print(elements[i].getDescription()+",,");
      out.println();
   }  
   private void printSystemState(float t) {
      if (elements == null) return;
      out.print(t+",");
      for (int i=0; i<elements.length; i++)
         out.print(elements[i].getState()+",,");  // print each element state
      out.println();
   }        
   public void simulate (float delta_t, float time, float deltaSample) {
      if (elements == null) {
         out.println("There is no element to simulate");
         return;
      }
      printSystemHeaders();
      for (float t=0, samplingTime=0; t<time; t+=delta_t){
         if (t >= samplingTime) {       // decide if it is time to print state 
            printSystemState(t);
            samplingTime += deltaSample;
         } 
         for (int i=0; i<elements.length; i++)   // for each element
            elements[i].computeNextState(delta_t); // compute next state
         for (int i=0; i<elements.length; i++)  // for all elements
            elements[i].updateState();         // update its state
      }
   }
}
